@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import asyncio
 import logging
+import re
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any, Literal, cast
 
@@ -22,8 +23,13 @@ from .constants import (
     API_VERSION_ERROR_MSG,
     API_VERSIONS,
     FIRMWARE_VERSION_ERROR_MSG,
+    HOT_WATER_CONFIG_PARAMS,
+    HOT_WATER_ESSENTIAL_PARAMS,
+    HOT_WATER_SCHEDULE_PARAMS,
     HVAC_MODE_DICT,
     HVAC_MODE_DICT_REVERSE,
+    MAX_VALID_YEAR,
+    MIN_VALID_YEAR,
     MULTI_PARAMETER_ERROR_MSG,
     NO_STATE_ERROR_MSG,
     SESSION_NOT_INITIALIZED_ERROR_MSG,
@@ -40,7 +46,10 @@ from .exceptions import (
 )
 from .models import (
     Device,
+    DeviceTime,
     DHWTimeSwitchPrograms,
+    HotWaterConfig,
+    HotWaterSchedule,
     HotWaterState,
     Info,
     Sensor,
@@ -88,6 +97,7 @@ class BSBLAN:
     _initialized: bool = False
     _api_validator: APIValidator = field(init=False)
     _temperature_unit: str = "°C"
+    _hot_water_param_cache: dict[str, str] = field(default_factory=dict)
 
     async def __aenter__(self) -> Self:
         """Enter the context manager.
@@ -185,12 +195,36 @@ class BSBLAN:
             # Update API data with validated configuration
             if self._api_data:
                 self._api_data[section] = api_validator.get_section_params(section)
+
+            # Cache hot water parameters if this is the hot_water section
+            if section == "hot_water":
+                self._populate_hot_water_cache()
         except BSBLANError as err:
             logger.warning("Failed to validate section %s: %s", section, str(err))
             # Reset validation state for this section
             api_validator.reset_validation(section)
             raise
 
+    def _populate_hot_water_cache(self) -> None:
+        """Populate the hot water parameter cache with all available parameters."""
+        if not self._api_validator:
+            return
+
+        # Get all hot water parameters and cache them
+        hotwater_params = self._api_validator.get_section_params("hot_water")
+        self._hot_water_param_cache = hotwater_params.copy()
+        logger.debug("Cached %d hot water parameters", len(self._hot_water_param_cache))
+
+    def set_hot_water_cache(self, params: dict[str, str]) -> None:
+        """Set the hot water parameter cache manually (for testing).
+
+        Args:
+            params: Dictionary of parameter_id -> parameter_name mappings
+
+        """
+        self._hot_water_param_cache = params.copy()
+        logger.debug("Manually set cache with %d hot water parameters", len(params))
+
     async def _fetch_firmware_version(self) -> None:
         """Fetch the firmware version if not already available."""
         if self._firmware_version is None:
@@ -324,8 +358,10 @@ class BSBLAN:
             raise BSBLANConnectionError(BSBLANConnectionError.message_error) from e
         except aiohttp.ClientError as e:
             raise BSBLANConnectionError(BSBLANConnectionError.message_error) from e
-        except ValueError as e:
-            raise BSBLANError(str(e)) from e
+        except (ValueError, UnicodeDecodeError) as e:
+            # Handle JSON decode errors and other parsing issues
+            error_msg = f"Invalid response format from BSB-LAN device: {e!s}"
+            raise BSBLANError(error_msg) from e
 
     def _process_response(
         self, response_data: dict[str, Any], base_path: str
@@ -494,6 +530,39 @@ class BSBLAN:
         data = dict(zip(params["list"], list(data.values()), strict=True))
         return Info.from_dict(data)
 
+    async def time(self) -> DeviceTime:
+        """Get the current time from the BSB-LAN device.
+
+        Returns:
+            DeviceTime: The current time information from the BSB-LAN device.
+
+        """
+        # Get only parameter 0 for time
+        data = await self._request(params={"Parameter": "0"})
+        # Create the data dictionary in the expected format
+        time_data = {"time": data["0"]}
+        return DeviceTime.from_dict(time_data)
+
+    async def set_time(self, time_value: str) -> None:
+        """Set the time on the BSB-LAN device.
+
+        Args:
+            time_value (str): The time value to set in format "DD.MM.YYYY HH:MM:SS"
+                (e.g., "13.08.2025 10:25:55").
+
+        Raises:
+            BSBLANInvalidParameterError: If the time format is invalid.
+
+        """
+        self._validate_time_format(time_value)
+        state: dict[str, object] = {
+            "Parameter": "0",
+            "Value": time_value,
+            "Type": "1",
+        }
+        response = await self._request(base_path="/JS", data=state)
+        logger.debug("Response for setting time: %s", response)
+
     async def thermostat(
         self,
         target_temperature: str | None = None,
@@ -543,7 +612,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "700",
-                    "EnumValue": HVAC_MODE_DICT_REVERSE[hvac_mode],
+                    "Value": str(HVAC_MODE_DICT_REVERSE[hvac_mode]),
                     "Type": "1",
                 },
             )
@@ -583,6 +652,58 @@ class BSBLAN:
         if hvac_mode not in HVAC_MODE_DICT_REVERSE:
             raise BSBLANInvalidParameterError(hvac_mode)
 
+    def _validate_time_format(self, time_value: str) -> None:
+        """Validate the time format.
+
+        Args:
+            time_value (str): The time value to validate.
+
+        Raises:
+            BSBLANInvalidParameterError: If the time format is invalid.
+
+        """
+        # BSB-LAN supports format: DD.MM.YYYY HH:MM:SS (e.g., "13.08.2025 10:25:55")
+        pattern = r"^(\d{2})\.(\d{2})\.(\d{4}) (\d{2}):(\d{2}):(\d{2})$"
+
+        match = re.match(pattern, time_value)
+        if not match:
+            msg = f"Invalid time format: {time_value}. Expected DD.MM.YYYY HH:MM:SS"
+            raise BSBLANInvalidParameterError(msg)
+
+        day, month, year, hour, minute, second = map(int, match.groups())
+
+        # Validate ranges
+        if not (1 <= day <= 31):
+            msg = f"Invalid day: {day}"
+            raise BSBLANInvalidParameterError(msg)
+        if not (1 <= month <= 12):
+            msg = f"Invalid month: {month}"
+            raise BSBLANInvalidParameterError(msg)
+        if not (MIN_VALID_YEAR <= year <= MAX_VALID_YEAR):
+            msg = f"Invalid year: {year}"
+            raise BSBLANInvalidParameterError(msg)
+        if not (0 <= hour <= 23):
+            msg = f"Invalid hour: {hour}"
+            raise BSBLANInvalidParameterError(msg)
+        if not (0 <= minute <= 59):
+            msg = f"Invalid minute: {minute}"
+            raise BSBLANInvalidParameterError(msg)
+        if not (0 <= second <= 59):
+            msg = f"Invalid second: {second}"
+            raise BSBLANInvalidParameterError(msg)
+
+        # Additional validation for days per month
+        if month in [4, 6, 9, 11] and day > 30:
+            msg = f"Invalid day {day} for month {month}"
+            raise BSBLANInvalidParameterError(msg)
+        if month == 2:
+            # Leap year check
+            is_leap = (year % 4 == 0 and year % 100 != 0) or (year % 400 == 0)
+            max_day = 29 if is_leap else 28
+            if day > max_day:
+                msg = f"Invalid day {day} for February in year {year}"
+                raise BSBLANInvalidParameterError(msg)
+
     async def _set_thermostat_state(self, state: dict[str, Any]) -> None:
         """Set the thermostat state.
 
@@ -594,18 +715,96 @@ class BSBLAN:
         logger.debug("Response for setting: %s", response)
 
     async def hot_water_state(self) -> HotWaterState:
-        """Get the current hot water state from BSBLAN device.
+        """Get essential hot water state for frequent polling.
+
+        This method returns only the most important hot water parameters
+        that are typically checked frequently for monitoring purposes.
+        This reduces API calls and improves performance for regular polling.
 
         Returns:
-            HotWaterState: The current hot water state.
+            HotWaterState: Essential hot water state information.
 
         """
-        hotwater_params = self._api_validator.get_section_params("hot_water")
-        params = await self._extract_params_summary(hotwater_params)
+        # Use cached parameters or fall back to API validator
+        hotwater_params = (
+            self._hot_water_param_cache
+            or self._api_validator.get_section_params("hot_water")
+        )
+        essential_params = {
+            param_id: param_name
+            for param_id, param_name in hotwater_params.items()
+            if param_id in HOT_WATER_ESSENTIAL_PARAMS
+        }
+
+        if not essential_params:
+            msg = "No essential hot water parameters available"
+            raise BSBLANError(msg)
+
+        params = await self._extract_params_summary(essential_params)
         data = await self._request(params={"Parameter": params["string_par"]})
         data = dict(zip(params["list"], list(data.values()), strict=True))
         return HotWaterState.from_dict(data)
 
+    async def hot_water_config(self) -> HotWaterConfig:
+        """Get hot water configuration and advanced settings.
+
+        This method returns configuration parameters that are typically
+        set once and checked less frequently.
+
+        Returns:
+            HotWaterConfig: Hot water configuration information.
+
+        """
+        # Use cached parameters or fall back to API validator
+        hotwater_params = (
+            self._hot_water_param_cache
+            or self._api_validator.get_section_params("hot_water")
+        )
+        config_params = {
+            param_id: param_name
+            for param_id, param_name in hotwater_params.items()
+            if param_id in HOT_WATER_CONFIG_PARAMS
+        }
+
+        if not config_params:
+            msg = "No hot water configuration parameters available"
+            raise BSBLANError(msg)
+
+        params = await self._extract_params_summary(config_params)
+        data = await self._request(params={"Parameter": params["string_par"]})
+        data = dict(zip(params["list"], list(data.values()), strict=True))
+        return HotWaterConfig.from_dict(data)
+
+    async def hot_water_schedule(self) -> HotWaterSchedule:
+        """Get hot water time program schedules.
+
+        This method returns time program settings that are typically
+        configured once and rarely changed.
+
+        Returns:
+            HotWaterSchedule: Hot water schedule information.
+
+        """
+        # Use cached parameters or fall back to API validator
+        hotwater_params = (
+            self._hot_water_param_cache
+            or self._api_validator.get_section_params("hot_water")
+        )
+        schedule_params = {
+            param_id: param_name
+            for param_id, param_name in hotwater_params.items()
+            if param_id in HOT_WATER_SCHEDULE_PARAMS
+        }
+
+        if not schedule_params:
+            msg = "No hot water schedule parameters available"
+            raise BSBLANError(msg)
+
+        params = await self._extract_params_summary(schedule_params)
+        data = await self._request(params={"Parameter": params["string_par"]})
+        data = dict(zip(params["list"], list(data.values()), strict=True))
+        return HotWaterSchedule.from_dict(data)
+
     async def set_hot_water(  # noqa: PLR0913
         self,
         nominal_setpoint: float | None = None,
@@ -749,7 +948,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1600",
-                    "EnumValue": operating_mode,
+                    "Value": str(operating_mode),
                     "Type": "1",
                 },
             )
@@ -757,7 +956,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1601",
-                    "EnumValue": eco_mode_selection,
+                    "Value": str(eco_mode_selection),
                     "Type": "1",
                 },
             )
@@ -765,7 +964,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1630",
-                    "EnumValue": dhw_charging_priority,
+                    "Value": str(dhw_charging_priority),
                     "Type": "1",
                 },
             )
@@ -781,7 +980,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1647",
-                    "EnumValue": legionella_circulation_pump,
+                    "Value": str(legionella_circulation_pump),
                     "Type": "1",
                 },
             )
@@ -797,7 +996,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1660",
-                    "EnumValue": dhw_circulation_pump_release,
+                    "Value": str(dhw_circulation_pump_release),
                     "Type": "1",
                 },
             )
@@ -821,7 +1020,7 @@ class BSBLAN:
             state.update(
                 {
                     "Parameter": "1680",
-                    "EnumValue": operating_mode_changeover,
+                    "Value": str(operating_mode_changeover),
                     "Type": "1",
                 },
             )
